
function [Ms,Mspeak]=minbodems(num,den,gain,deadtime,w)
%Frequency analysis of SISO system L= gain*deadtime*num/den
%By Truls Larsson, Trondheim 15.09.98 and 21.09.98
%
%Kall:  minbodems(num,den,gain,deadtime,w) 
%gir:   verdier av S=1/1+L; 

%Input:
%num      : er teller polynomet
%den      : er nevner polynomet
%gain     : er forsterkning
%deadtime : er dodtid
%w        : er frekvensene (NB! omraadet maa vaere stort nok)
%Eksempel:
%num=[2 1]; den=[25 10 1 0];  gain=0.1; deadtime=3; w= logspace(-2,2,100);
%
 

%Frekvensresponsen
teller=polyval(num,w*i);
nevner=polyval(den,w*i);
Dod   =exp(-deadtime*w*i);
Frek=gain*teller./nevner.*Dod;  % korrigert av SiS


%Beregning av S og T
S=1./abs(1+Frek);
Ms(1) = S(1); Ms(2)=S(300); Ms(3)=S(400); Ms(4)=S(450); Ms(5)=S(500); 
Ms(6)=S(550); Ms(7)=S(600); Ms(8)=S(700); Ms(9)=S(1000); 
Mspeak=max(S);



